==> Xarm-1.2.7.tar.gz: Xarm-1.2.7/include/Xarm/Core.h <==
/* $Id: Core.h,v 1.2 1997/04/08 15:31:58 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_CORE_H_)
#define _XARM_CORE_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/RectObj.h>
#include <Xarm/XarmArg.h>

class CoreClass : public _RectObjClass {
 protected:
   CoreClass() {} /* only a derived class can make this */
   virtual WidgetClass classPointer() { return coreWidgetClass; }
   virtual _XtString className() { return (_XtString) "Core"; }
 public:
   /* resources */
   void accelerators(XtAccelerators);
   XtAccelerators accelerators();
   void background(Pixel);
   Pixel background();
   void backgroundPixmap(Pixmap);
   Pixmap backgroundPixmap();
   void borderColor(Pixel);
   Pixel borderColor();
   void borderPixmap(Pixmap);
   Pixmap borderPixmap();
   Colormap colormap();
   int depth();
   Boolean mappedWhenManaged();
   void mappedWhenManaged(Boolean);
   Screen *screen();
   XtTranslations translations();
   void translations(XtTranslations);

   /* extra functionality */
   void backgroundPixmap(char *);

};

#endif

==> Xarm-1.3.0.tar.gz: Xarm-1.3.0/include/Xarm/Core.h <==
/* $Id: Core.h,v 1.4 1999/01/15 01:47:15 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_CORE_H_)
#define _XARM_CORE_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/RectObj.h>
#include <Xarm/XarmArg.h>

class CoreClass : public _RectObjClass {
 protected:
   CoreClass() {} /* only a derived class can make this */
   virtual WidgetClass classPointer() { return coreWidgetClass; }
   virtual _XtString className() { return (_XtString) "Core"; }
 public:
   /* resources */
   void accelerators(const XtAccelerators);
   XtAccelerators accelerators() const;
   void  background(Pixel);
   Pixel background() const;
   void   backgroundPixmap(const Pixmap);
   Pixmap backgroundPixmap() const;
   void borderColor(Pixel);
   Pixel borderColor() const;
   void borderPixmap(const Pixmap);
   Pixmap borderPixmap() const;
   Colormap colormap() const;
   int depth() const;
   Boolean mappedWhenManaged() const;
   void mappedWhenManaged(Boolean);
   Screen *screen() const;
   XtTranslations translations() const;
   void translations(const XtTranslations);

   /* extra functionality */
   void background(const char *);
   void backgroundPixmap(const char *);
   void borderColor(const char *);

};

#endif
